Changelog
=========


1.5.0 (2022-12-13)
------------------
- Removed python 3.6 and 3.7 support updated to latest mutagen and
  youtube-dl versions. [Michael Pfister]
- Merge pull request #121 from pfitzer/pyup-update-youtube-
  dl-2021.1.16-to-2021.1.24.1. [Michael Pfister]


1.4.0 (2020-11-02)
------------------
- * changed README.rst * depends on latest youtube-dl version. [Michael
  Pfister]
- Merge pull request #97 from pfitzer/pyup-update-toml-0.10.1-to-0.10.2.
  [Michael Pfister]

  Update toml to 0.10.2
- Merge branch 'master' into pyup-update-toml-0.10.1-to-0.10.2. [Michael
  Pfister]
- Merge pull request #99 from pfitzer/pyup-update-youtube-
  dl-2020.9.20-to-2020.11.1.1. [Michael Pfister]

  Update youtube-dl to 2020.11.1.1
- Update youtube-dl from 2020.9.20 to 2020.11.1.1. [pyup-bot]
- Update toml from 0.10.1 to 0.10.2. [pyup-bot]
- Merge pull request #96 from pfitzer/issue#95. [Michael Pfister]

  Issue#95


1.3.0 (2020-10-15)
------------------
- #95 test with python 3.9. [Michael Pfister]
- #95 test with python 3.9. [Michael Pfister]
- Merge pull request #94 from pfitzer/pyup-update-youtube-
  dl-2020.9.14-to-2020.9.20. [Michael Pfister]

  Update youtube-dl to 2020.9.20
- Update youtube-dl from 2020.9.14 to 2020.9.20. [pyup-bot]
- Merge pull request #93 from pfitzer/pyup-update-youtube-
  dl-2020.9.6-to-2020.9.14. [Michael Pfister]

  Update youtube-dl to 2020.9.14
- Update youtube-dl from 2020.9.6 to 2020.9.14. [pyup-bot]
- Merge pull request #92 from pfitzer/pyup-update-youtube-
  dl-2020.7.28-to-2020.9.6. [Michael Pfister]

  Update youtube-dl to 2020.9.6
- Update youtube-dl from 2020.7.28 to 2020.9.6. [pyup-bot]
- Merge pull request #91 from pfitzer/pyup-update-
  mutagen-1.45.0-to-1.45.1. [Michael Pfister]

  Update mutagen to 1.45.1
- Update mutagen from 1.45.0 to 1.45.1. [pyup-bot]


1.2.0 (2020-07-28)
------------------
- Use newest versions of youtube_dl and mutagen. [Michael Pfister]
- Merge pull request #90 from pfitzer/pyup-update-youtube-
  dl-2020.6.16.1-to-2020.7.28. [Michael Pfister]

  Update youtube-dl to 2020.7.28
- Update youtube-dl from 2020.6.16.1 to 2020.7.28. [pyup-bot]
- Updated README.rst. [Michael Pfister]
- Merge pull request #89 from pfitzer/pyup-update-
  mutagen-1.44.0-to-1.45.0. [Michael Pfister]

  Update mutagen to 1.45.0
- Update mutagen from 1.44.0 to 1.45.0. [pyup-bot]
- Create python-publish.yml. [Michael Pfister]
- Merge pull request #88 from pfitzer/pyup-update-youtube-
  dl-2020.6.6-to-2020.6.16.1. [Michael Pfister]

  Update youtube-dl to 2020.6.16.1
- Update youtube-dl from 2020.6.6 to 2020.6.16.1. [pyup-bot]
- Update README.rst. [Michael Pfister]
- Update README.rst. [Michael Pfister]
- Merge pull request #87 from pfitzer/pyup-update-youtube-
  dl-2020.5.29-to-2020.6.6. [Michael Pfister]

  Update youtube-dl to 2020.6.6
- Update youtube-dl from 2020.5.29 to 2020.6.6. [pyup-bot]
- Changelog. [Michael Pfister]


1.1.0 (2020-06-02)
------------------
- Posibility to use a file with yt urls. [Michael Pfister]
- Update unittest.yml. [Michael Pfister]
- Update unittest.yml. [Michael Pfister]
- Merge pull request #86 from pfitzer/pyup-update-youtube-
  dl-2020.5.8-to-2020.5.29. [Michael Pfister]

  Update youtube-dl to 2020.5.29
- Update youtube-dl from 2020.5.8 to 2020.5.29. [pyup-bot]
- Merge pull request #85 from pfitzer/pyup-update-toml-0.10.0-to-0.10.1.
  [Michael Pfister]

  Update toml to 0.10.1
- Update toml from 0.10.0 to 0.10.1. [pyup-bot]
- Merge pull request #84 from pfitzer/pyup-update-youtube-
  dl-2020.5.3-to-2020.5.8. [Michael Pfister]

  Update youtube-dl to 2020.5.8
- Update youtube-dl from 2020.5.3 to 2020.5.8. [pyup-bot]
- Merge pull request #83 from pfitzer/pyup-update-youtube-
  dl-2020.3.24-to-2020.5.3. [Michael Pfister]

  Update youtube-dl to 2020.5.3
- Update youtube-dl from 2020.3.24 to 2020.5.3. [pyup-bot]
- Update README.rst. [Michael Pfister]
- Update README.rst. [Michael Pfister]
- Merge pull request #82 from pfitzer/pyup-update-youtube-
  dl-2020.3.8-to-2020.3.24. [Michael Pfister]

  Update youtube-dl to 2020.3.24
- Update youtube-dl from 2020.3.8 to 2020.3.24. [pyup-bot]
- Update unittest.yml. [Michael Pfister]
- Update unittest.yml. [Michael Pfister]

  testing with python 3.9
- Merge pull request #81 from pfitzer/pyup-update-youtube-
  dl-2020.3.6-to-2020.3.8. [Michael Pfister]

  Update youtube-dl to 2020.3.8
- Update youtube-dl from 2020.3.6 to 2020.3.8. [pyup-bot]
- Merge pull request #80 from pfitzer/pyup-update-youtube-
  dl-2020.3.1-to-2020.3.6. [Michael Pfister]

  Update youtube-dl to 2020.3.6
- Update youtube-dl from 2020.3.1 to 2020.3.6. [pyup-bot]


1.0.0 (2020-03-02)
------------------
- Use versions for dependecies. [Michael Pfister]
- Merge pull request #79 from pfitzer/pyup-update-youtube-
  dl-2020.2.16-to-2020.3.1. [Michael Pfister]

  Update youtube-dl to 2020.3.1
- Update youtube-dl from 2020.2.16 to 2020.3.1. [pyup-bot]
- Merge pull request #78 from pfitzer/pyup-update-youtube-
  dl-2020.1.24-to-2020.2.16. [Michael Pfister]

  Update youtube-dl to 2020.2.16
- Update youtube-dl from 2020.1.24 to 2020.2.16. [pyup-bot]
- Update README.rst. [Michael Pfister]
- Changlog. [Michael Pfister]
- Skipped python 2.7 support. [Michael Pfister]


0.9.0 (2020-02-10)
------------------
- Merge pull request #77 from pfitzer/pyup-update-
  mutagen-1.42.0-to-1.44.0. [Michael Pfister]

  Update mutagen to 1.44.0
- Update mutagen from 1.42.0 to 1.44.0. [pyup-bot]
- Skipped python 2.7 support. [Michael Pfister]
- Update unittest.yml. [Michael Pfister]

  run test on python 3.8
- Merge pull request #76 from pfitzer/pyup-update-youtube-
  dl-2020.1.15-to-2020.1.24. [Michael Pfister]

  Update youtube-dl to 2020.1.24
- Update youtube-dl from 2020.1.15 to 2020.1.24. [pyup-bot]
- Merge pull request #75 from pfitzer/pyup-update-youtube-
  dl-2020.1.1-to-2020.1.15. [Michael Pfister]

  Update youtube-dl to 2020.1.15
- Update youtube-dl from 2020.1.1 to 2020.1.15. [pyup-bot]
- Merge pull request #74 from pfitzer/pyup-update-youtube-
  dl-2019.12.25-to-2020.1.1. [Michael Pfister]

  Update youtube-dl to 2020.1.1
- Update youtube-dl from 2019.12.25 to 2020.1.1. [pyup-bot]
- Merge pull request #73 from pfitzer/pyup-update-youtube-
  dl-2019.11.28-to-2019.12.25. [Michael Pfister]

  Update youtube-dl to 2019.12.25
- Update youtube-dl from 2019.11.28 to 2019.12.25. [pyup-bot]
- Merge pull request #72 from pfitzer/pyup-update-youtube-
  dl-2019.11.22-to-2019.11.28. [Michael Pfister]

  Update youtube-dl to 2019.11.28
- Update youtube-dl from 2019.11.22 to 2019.11.28. [pyup-bot]
- Merge pull request #71 from pfitzer/pyup-update-youtube-
  dl-2019.11.5-to-2019.11.22. [Michael Pfister]

  Update youtube-dl to 2019.11.22
- Update youtube-dl from 2019.11.5 to 2019.11.22. [pyup-bot]
- Merge pull request #70 from pfitzer/pyup-update-youtube-
  dl-2019.10.29-to-2019.11.5. [Michael Pfister]

  Update youtube-dl to 2019.11.5
- Update youtube-dl from 2019.10.29 to 2019.11.5. [pyup-bot]
- Merge pull request #69 from pfitzer/pyup-update-youtube-
  dl-2019.10.22-to-2019.10.29. [Michael Pfister]

  Update youtube-dl to 2019.10.29
- Update youtube-dl from 2019.10.22 to 2019.10.29. [pyup-bot]
- Merge pull request #68 from pfitzer/pyup-update-youtube-
  dl-2019.10.16-to-2019.10.22. [Michael Pfister]

  Update youtube-dl to 2019.10.22
- Update youtube-dl from 2019.10.16 to 2019.10.22. [pyup-bot]
- Merge pull request #67 from pfitzer/pyup-update-youtube-
  dl-2019.9.28-to-2019.10.16. [Michael Pfister]

  Update youtube-dl to 2019.10.16
- Update youtube-dl from 2019.9.28 to 2019.10.16. [pyup-bot]
- Merge pull request #66 from pfitzer/pyup-update-youtube-
  dl-2019.9.12.1-to-2019.9.28. [Michael Pfister]

  Update youtube-dl to 2019.9.28
- Update youtube-dl from 2019.9.12.1 to 2019.9.28. [pyup-bot]
- Update unittest.yml. [Michael Pfister]
- Merge pull request #65 from pfitzer/pyup-update-youtube-
  dl-2019.9.1-to-2019.9.12.1. [Michael Pfister]

  Update youtube-dl to 2019.9.12.1
- Update youtube-dl from 2019.9.1 to 2019.9.12.1. [pyup-bot]
- Updated dependencies. [Michael Pfister]
- Switch from travis to github actions. [Michael Pfister]
- Switch from travis to github actions. [Michael Pfister]
- Test github actions. [Michael Pfister]
- Test github actions. [Michael Pfister]
- Update pythonpackage.yml. [Michael Pfister]
- Changelog. [Michael Pfister]


0.8.0 (2019-08-26)
------------------
- # fixed exception if video name does not match # use tmp dir for
  download. [Michael Pfister]


0.7.0 (2019-08-24)
------------------
- Fixed unit tests. [Michael Pfister]
- Fixed unit tests. [Michael Pfister]
- Fixed path in unittest. [Michael Pfister]
- Unittest. [Michael Pfister]
- Fixed python 3 import error. [Michael Pfister]
- Fixed python 3 import error. [Michael Pfister]
- Update README.rst. [Michael Pfister]
- Update README.rst. [Michael Pfister]


0.6.0 (2019-03-11)
------------------
- Latest youtube-dl; change to pipenv. [Michael Pfister]
- Merge pull request #62 from pfitzer/pyup-update-youtube-
  dl-2019.3.1-to-2019.3.9. [Michael Pfister]

  Update youtube-dl to 2019.3.9
- Update youtube-dl from 2019.3.1 to 2019.3.9. [pyup-bot]
- Merge pull request #61 from pfitzer/pyup-update-youtube-
  dl-2019.2.18-to-2019.3.1. [Michael Pfister]

  Update youtube-dl to 2019.3.1
- Update youtube-dl from 2019.2.18 to 2019.3.1. [pyup-bot]
- Merge pull request #60 from pfitzer/pyup-update-youtube-
  dl-2019.2.8-to-2019.2.18. [Michael Pfister]

  Update youtube-dl to 2019.2.18
- Update youtube-dl from 2019.2.8 to 2019.2.18. [pyup-bot]
- Merge pull request #59 from pfitzer/pyup-update-youtube-
  dl-2019.1.30.1-to-2019.2.8. [Michael Pfister]

  Update youtube-dl to 2019.2.8
- Update youtube-dl from 2019.1.30.1 to 2019.2.8. [pyup-bot]
- Merge pull request #58 from pfitzer/pyup-update-youtube-
  dl-2019.1.27-to-2019.1.30.1. [Michael Pfister]

  Update youtube-dl to 2019.1.30.1
- Update youtube-dl from 2019.1.27 to 2019.1.30.1. [pyup-bot]
- Merge pull request #56 from pfitzer/pyup-update-youtube-
  dl-2019.1.24-to-2019.1.27. [Michael Pfister]

  Update youtube-dl to 2019.1.27
- Update youtube-dl from 2019.1.24 to 2019.1.27. [pyup-bot]
- Merge pull request #55 from pfitzer/pyup-update-youtube-
  dl-2019.1.23-to-2019.1.24. [Michael Pfister]

  Update youtube-dl to 2019.1.24
- Update youtube-dl from 2019.1.23 to 2019.1.24. [pyup-bot]
- Merge pull request #54 from pfitzer/pyup-update-youtube-
  dl-2019.1.17-to-2019.1.23. [Michael Pfister]

  Update youtube-dl to 2019.1.23
- Update youtube-dl from 2019.1.17 to 2019.1.23. [pyup-bot]
- Merge pull request #53 from pfitzer/pyup-update-youtube-
  dl-2019.1.16-to-2019.1.17. [Michael Pfister]

  Update youtube-dl to 2019.1.17
- Update youtube-dl from 2019.1.16 to 2019.1.17. [pyup-bot]
- Merge pull request #52 from pfitzer/pyup-update-youtube-
  dl-2019.1.10-to-2019.1.16. [Michael Pfister]

  Update youtube-dl to 2019.1.16
- Update youtube-dl from 2019.1.10 to 2019.1.16. [pyup-bot]
- Merge pull request #51 from pfitzer/pyup-update-youtube-
  dl-2019.1.2-to-2019.1.10. [Michael Pfister]

  Update youtube-dl to 2019.1.10
- Update youtube-dl from 2019.1.2 to 2019.1.10. [pyup-bot]
- Merge pull request #50 from pfitzer/pyup-update-youtube-
  dl-2018.12.17-to-2019.1.2. [Michael Pfister]

  Update youtube-dl to 2019.1.2
- Update youtube-dl from 2018.12.17 to 2019.1.2. [pyup-bot]
- Merge pull request #48 from pfitzer/pyup-update-
  mutagen-1.41.1-to-1.42.0. [Michael Pfister]

  Update mutagen to 1.42.0
- Update mutagen from 1.41.1 to 1.42.0. [pyup-bot]
- Merge pull request #47 from pfitzer/pyup-update-
  gitchangelog-3.0.3-to-3.0.4. [Michael Pfister]

  Update gitchangelog to 3.0.4
- Update gitchangelog from 3.0.3 to 3.0.4. [pyup-bot]
- Merge pull request #46 from pfitzer/pyup-update-youtube-
  dl-2018.12.9-to-2018.12.17. [Michael Pfister]

  Update youtube-dl to 2018.12.17
- Update youtube-dl from 2018.12.9 to 2018.12.17. [pyup-bot]
- Merge pull request #45 from pfitzer/pyup-update-youtube-
  dl-2018.12.3-to-2018.12.9. [Michael Pfister]

  Update youtube-dl to 2018.12.9
- Update youtube-dl from 2018.12.3 to 2018.12.9. [pyup-bot]
- Merge pull request #44 from pfitzer/pyup-update-youtube-
  dl-2018.11.23-to-2018.12.3. [Michael Pfister]

  Update youtube-dl to 2018.12.3
- Update youtube-dl from 2018.11.23 to 2018.12.3. [pyup-bot]


0.5.0 (2018-11-23)
------------------
- Merge pull request #43 from pfitzer/pyup-update-youtube-
  dl-2018.11.18-to-2018.11.23. [Michael Pfister]

  Update youtube-dl to 2018.11.23
- Update youtube-dl from 2018.11.18 to 2018.11.23. [pyup-bot]
- Merge pull request #42 from pfitzer/pyup-update-youtube-
  dl-2018.11.7-to-2018.11.18. [Michael Pfister]

  Update youtube-dl to 2018.11.18
- Update youtube-dl from 2018.11.7 to 2018.11.18. [pyup-bot]
- Merge pull request #41 from pfitzer/pyup-update-youtube-
  dl-2018.10.29-to-2018.11.7. [Michael Pfister]

  Update youtube-dl to 2018.11.7
- Update youtube-dl from 2018.10.29 to 2018.11.7. [pyup-bot]
- Merge pull request #39 from pfitzer/pyup-update-youtube-
  dl-2018.10.5-to-2018.10.29. [Michael Pfister]

  Update youtube-dl to 2018.10.29
- Update youtube-dl from 2018.10.5 to 2018.10.29. [pyup-bot]
- Merge pull request #38 from pfitzer/pyup-update-youtube-
  dl-2018.9.26-to-2018.10.5. [Michael Pfister]

  Update youtube-dl to 2018.10.5
- Update youtube-dl from 2018.9.26 to 2018.10.5. [pyup-bot]
- Merge pull request #37 from pfitzer/pyup-update-youtube-
  dl-2018.9.18-to-2018.9.26. [Michael Pfister]

  Update youtube-dl to 2018.9.26
- Update youtube-dl from 2018.9.18 to 2018.9.26. [pyup-bot]
- Merge pull request #36 from pfitzer/pyup-update-youtube-
  dl-2018.9.10-to-2018.9.18. [Michael Pfister]

  Update youtube-dl to 2018.9.18
- Update youtube-dl from 2018.9.10 to 2018.9.18. [pyup-bot]
- Merge pull request #35 from pfitzer/pyup-update-youtube-
  dl-2018.9.8-to-2018.9.10. [Michael Pfister]

  Update youtube-dl to 2018.9.10
- Update youtube-dl from 2018.9.8 to 2018.9.10. [pyup-bot]
- Merge pull request #34 from pfitzer/pyup-update-youtube-
  dl-2018.8.28-to-2018.9.8. [Michael Pfister]

  Update youtube-dl to 2018.9.8
- Update youtube-dl from 2018.8.28 to 2018.9.8. [pyup-bot]
- Merge pull request #33 from pfitzer/pyup-update-youtube-
  dl-2018.8.22-to-2018.8.28. [Michael Pfister]

  Update youtube-dl to 2018.8.28
- Update youtube-dl from 2018.8.22 to 2018.8.28. [pyup-bot]
- Merge pull request #32 from pfitzer/pyup-update-youtube-
  dl-2018.8.4-to-2018.8.22. [Michael Pfister]

  Update youtube-dl to 2018.8.22
- Update youtube-dl from 2018.8.4 to 2018.8.22. [pyup-bot]
- Merge pull request #31 from pfitzer/pyup-update-
  mutagen-1.41.0-to-1.41.1. [Michael Pfister]

  Update mutagen to 1.41.1
- Update mutagen from 1.41.0 to 1.41.1. [pyup-bot]
- Merge pull request #30 from pfitzer/pyup-update-youtube-
  dl-2018.7.29-to-2018.8.4. [Michael Pfister]

  Update youtube-dl to 2018.8.4
- Update youtube-dl from 2018.7.29 to 2018.8.4. [pyup-bot]
- Merge pull request #29 from pfitzer/pyup-update-youtube-
  dl-2018.7.21-to-2018.7.29. [Michael Pfister]

  Update youtube-dl to 2018.7.29
- Update youtube-dl from 2018.7.21 to 2018.7.29. [pyup-bot]
- Merge pull request #28 from pfitzer/pyup-update-youtube-
  dl-2018.7.10-to-2018.7.21. [Michael Pfister]

  Update youtube-dl to 2018.7.21
- Update youtube-dl from 2018.7.10 to 2018.7.21. [pyup-bot]
- Merge pull request #27 from pfitzer/pyup-update-
  mutagen-1.40.0-to-1.41.0. [Michael Pfister]

  Update mutagen to 1.41.0
- Update mutagen from 1.40.0 to 1.41.0. [pyup-bot]
- Merge pull request #26 from pfitzer/pyup-update-youtube-
  dl-2018.7.4-to-2018.7.10. [Michael Pfister]

  Update youtube-dl to 2018.7.10
- Update youtube-dl from 2018.7.4 to 2018.7.10. [pyup-bot]
- Merge pull request #25 from pfitzer/pyup-update-youtube-
  dl-2018.6.25-to-2018.7.4. [Michael Pfister]

  Update youtube-dl to 2018.7.4
- Update youtube-dl from 2018.6.25 to 2018.7.4. [pyup-bot]
- Changed readme. [Michael Pfister]
- Changelog. [micpfist]
- Update issue templates. [Michael Pfister]
- Create PULL_REQUEST_TEMPLATE.md. [Michael Pfister]
- Create CONTRIBUTING.md. [Michael Pfister]
- Update issue templates. [Michael Pfister]
- Merge pull request #23 from pfitzer/add-code-of-conduct-1. [Michael
  Pfister]

  Create CODE_OF_CONDUCT.md
- Create CODE_OF_CONDUCT.md. [Michael Pfister]
- Added version icon to readme. [pfitzer]
- Changede license cause of used mutagen. [pfitzer]


0.4.3 (2018-06-30)
------------------
- Merge pull request #22 from pfitzer/pyup-update-youtube-
  dl-2018.6.19-to-2018.6.25. [Michael Pfister]

  Update youtube-dl to 2018.6.25
- Update youtube-dl from 2018.6.19 to 2018.6.25. [pyup-bot]
- Merge pull request #21 from pfitzer/pyup-update-youtube-
  dl-2018.6.18-to-2018.6.19. [Michael Pfister]

  Update youtube-dl to 2018.6.19
- Update youtube-dl from 2018.6.18 to 2018.6.19. [pyup-bot]
- Merge pull request #20 from pfitzer/pyup-update-youtube-
  dl-2018.6.14-to-2018.6.18. [Michael Pfister]

  Update youtube-dl to 2018.6.18
- Update youtube-dl from 2018.6.14 to 2018.6.18. [pyup-bot]
- Merge pull request #19 from pfitzer/pyup-update-youtube-
  dl-2018.6.11-to-2018.6.14. [Michael Pfister]

  Update youtube-dl to 2018.6.14
- Update youtube-dl from 2018.6.11 to 2018.6.14. [pyup-bot]
- Merge pull request #18 from pfitzer/pyup-update-youtube-
  dl-2018.6.4-to-2018.6.11. [Michael Pfister]

  Update youtube-dl to 2018.6.11
- Update youtube-dl from 2018.6.4 to 2018.6.11. [pyup-bot]
- Merge pull request #17 from pfitzer/pyup-update-youtube-
  dl-2018.5.30-to-2018.6.4. [Michael Pfister]

  Update youtube-dl to 2018.6.4
- Update youtube-dl from 2018.5.30 to 2018.6.4. [pyup-bot]
- Merge pull request #15 from pfitzer/pyup-update-youtube-
  dl-2018.5.26-to-2018.5.30. [Michael Pfister]

  Update youtube-dl to 2018.5.30
- Update youtube-dl from 2018.5.26 to 2018.5.30. [pyup-bot]
- Merge pull request #14 from pfitzer/pyup-update-youtube-
  dl-2018.5.18-to-2018.5.26. [Michael Pfister]

  Update youtube-dl to 2018.5.26
- Update youtube-dl from 2018.5.18 to 2018.5.26. [pyup-bot]
- Merge pull request #13 from pfitzer/pyup-update-youtube-
  dl-2018.5.9-to-2018.5.18. [Michael Pfister]

  Update youtube-dl to 2018.5.18
- Update youtube-dl from 2018.5.9 to 2018.5.18. [pyup-bot]
- Merge pull request #12 from pfitzer/pyup-update-youtube-
  dl-2018.5.1-to-2018.5.9. [Michael Pfister]

  Update youtube-dl to 2018.5.9
- Update youtube-dl from 2018.5.1 to 2018.5.9. [pyup-bot]
- Merge pull request #11 from pfitzer/pyup-update-youtube-
  dl-2018.4.25-to-2018.5.1. [Michael Pfister]

  Update youtube-dl to 2018.5.1
- Update youtube-dl from 2018.4.25 to 2018.5.1. [pyup-bot]
- Merge pull request #10 from pfitzer/pyup-update-youtube-
  dl-2018.4.9-to-2018.4.25. [Michael Pfister]

  Update youtube-dl to 2018.4.25
- Update youtube-dl from 2018.4.9 to 2018.4.25. [pyup-bot]
- Changelog. [micpfist]


0.4.2 (2018-04-09)
------------------
- New version 0.4.2. [micpfist]
- Merge pull request #9 from pfitzer/pyup-update-youtube-
  dl-2018.3.20-to-2018.4.9. [Michael Pfister]

  Update youtube-dl to 2018.4.9
- Update youtube-dl from 2018.3.20 to 2018.4.9. [pyup-bot]
- Merge pull request #6 from pfitzer/pyup-update-youtube-
  dl-2018.3.14-to-2018.3.20. [Michael Pfister]

  Update youtube-dl to 2018.3.20
- Update youtube-dl from 2018.3.14 to 2018.3.20. [pyup-bot]
- Merge pull request #5 from pfitzer/pyup-update-youtube-
  dl-2018.3.10-to-2018.3.14. [Michael Pfister]

  Update youtube-dl to 2018.3.14
- Update youtube-dl from 2018.3.10 to 2018.3.14. [pyup-bot]
- Merge pull request #4 from pfitzer/pyup-update-youtube-
  dl-2018.3.3-to-2018.3.10. [Michael Pfister]

  Update youtube-dl to 2018.3.10
- Update youtube-dl from 2018.3.3 to 2018.3.10. [pyup-bot]
- Changede license cause of used mutagen. [pfitzer]
- Merge remote-tracking branch 'origin/master' [pfitzer]
- Merge pull request #3 from pfitzer/pyup-update-youtube-
  dl-2017.10.1-to-2018.3.3. [Michael Pfister]

  Update youtube-dl to 2018.3.3
- Merge branch 'master' into pyup-update-youtube-
  dl-2017.10.1-to-2018.3.3. [Michael Pfister]
- Update youtube-dl from 2017.10.1 to 2018.3.3. [pyup-bot]
- Readme. [pfitzer]
- Merge pull request #2 from pfitzer/pyup-update-mutagen-1.38-to-1.40.0.
  [Michael Pfister]

  Update mutagen to 1.40.0
- Update mutagen from 1.38 to 1.40.0. [pyup-bot]
- Pip requirements. [pfitzer]


0.4.1 (2017-10-04)
------------------
- Bugfix exception message. [pfitzer]
- Bugfix exception message. [pfitzer]
- Gitignore. [Michael Pfister]
- Python 3 compatible; pipenv for development. [Michael Pfister]


0.4.0 (2017-09-26)
------------------
- Python 3 compatible. [Michael Pfister]
- Changed documentation. [Michael Pfister]
- Added sphinx documentation. [Michael Pfister]
- Added pyc files to ignore. [Michael Pfister]
- Changelog. [Michael Pfister]


0.3.0 (2016-07-01)
------------------
- Class based. [Michael Pfister]
- Nicer readme. [Michael Pfister]


0.2.5 (2016-06-30)
------------------
- Bugfix: missing packages in setup.py. [Michael Pfister]
- Bugfix: missing packages in setup.py. [Michael Pfister]


0.2.4 (2016-06-30)
------------------
- Updated setup. [Michael Pfister]


0.2.3 (2016-06-30)
------------------
- Updated setup. [Michael Pfister]


0.2.2 (2016-06-30)
------------------
- Updated setup. [Michael Pfister]
- Some cleaning. [Michael Pfister]
- Readme. [Michael Pfister]
- Readme. [Michael Pfister]


0.2.1 (2016-06-30)
------------------
- Pip naming conventions and version. [Michael Pfister]
- Pip naming conventions. [Michael Pfister]
- Format readme. [Michael Pfister]
- Format readme. [Michael Pfister]
- Initial commit. [Michael Pfister]


